#ifndef QNETWORKREPLY_H
#define QNETWORKREPLY_H

#include <QByteArray>
#include <QBuffer>

class QNetworkReply
{
public:
    enum NetworkError {
        NoError = 0
    };

    QNetworkReply();
    ~QNetworkReply();
    QByteArray readAll();
    int error() const;
    void close();
    void deleteLater();
    QByteArray readLine(qint64 maxlen = 0);

    static QBuffer data;
};

#endif // QNETWORKREPLY_H

